==> tork-trinity-14.0.9.tar.xz: tork-trinity-14.0.9/src/testprivacyproxy.h <==
/****************************************************************************
 ** $Id: testprivacyproxy.h,v 1.2 2008/08/20 16:49:31 hoganrobert Exp $
 *   Copyright (C) 2006 - 2008 Robert Hogan                                *
 *   robert@roberthogan.net                                                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.              *
 ***************************************************************************
**
** Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
**
** This file is part of an example program for TQt.  This example
** program may be used, distributed and modified without limitation.
**
*****************************************************************************/

#ifndef _TESTPRIVACYPROXY_H_
#define _TESTPRIVACYPROXY_H_

#include <ntqsocket.h>
#include <ntqtextstream.h>
#include <kdebug.h>
#include <tdeconfigskeleton.h>
#include <ntqlistview.h>
#include "torkconfig.h"


class TestPrivoxy : public TQObject
{
    Q_OBJECT
public:
    TestPrivoxy( );

    virtual ~TestPrivoxy();


    void sendToServer(const TQString &string)
    {
        if (!socket)
            return;
        TQTextStream os(socket);
        os << string << "\r\n";
    }

public slots:
//     void socketReadyRead();

    void closeConnection()
    {
        socket->close();
        if ( socket->state() == TQSocket::Closing ) {
            // We have a delayed close.
            connect( socket, SIGNAL(delayedCloseFinished()),
                    SLOT(socketClosed()) );
        } else {
            // The socket is closed.
            socketClosed();
        }
    }

    void connectTo(const TQString &host, TQ_UINT16 port);

signals:

    void connectedToPrivacyProxy();
    void privacyProxyConnectionClosed();
    void fatalError();

private slots:


    void socketConnected()
    {
       emit connectedToPrivacyProxy();
    }

    void socketConnectionClosed()
    {
        emit privacyProxyConnectionClosed();
    }

    void socketClosed()
    {
    }

    void socketError( int e )
    {
         if ( e == TQSocket::ErrHostNotFound ||
              e == TQSocket::ErrConnectionRefused )
            emit fatalError();
    }


private:
    TQSocket *socket;
};

#endif //

==> tork-trinity-14.0.12.tar.xz: tork-trinity-14.0.12/src/testprivacyproxy.h <==
/****************************************************************************
 ** $Id: testprivacyproxy.h,v 1.2 2008/08/20 16:49:31 hoganrobert Exp $
 *   Copyright (C) 2006 - 2008 Robert Hogan                                *
 *   robert@roberthogan.net                                                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.              *
 ***************************************************************************
**
** Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
**
** This file is part of an example program for TQt.  This example
** program may be used, distributed and modified without limitation.
**
*****************************************************************************/

#ifndef _TESTPRIVACYPROXY_H_
#define _TESTPRIVACYPROXY_H_

#include <tqsocket.h>
#include <tqtextstream.h>
#include <tqlistview.h>

#include <kdebug.h>
#include <tdeconfigskeleton.h>

#include "torkconfig.h"


class TestPrivoxy : public TQObject
{
    Q_OBJECT
public:
    TestPrivoxy( );

    virtual ~TestPrivoxy();


    void sendToServer(const TQString &string)
    {
        if (!socket)
            return;
        TQTextStream os(socket);
        os << string << "\r\n";
    }

public slots:
//     void socketReadyRead();

    void closeConnection()
    {
        socket->close();
        if ( socket->state() == TQSocket::Closing ) {
            // We have a delayed close.
            connect( socket, SIGNAL(delayedCloseFinished()),
                    SLOT(socketClosed()) );
        } else {
            // The socket is closed.
            socketClosed();
        }
    }

    void connectTo(const TQString &host, TQ_UINT16 port);

signals:

    void connectedToPrivacyProxy();
    void privacyProxyConnectionClosed();
    void fatalError();

private slots:


    void socketConnected()
    {
       emit connectedToPrivacyProxy();
    }

    void socketConnectionClosed()
    {
        emit privacyProxyConnectionClosed();
    }

    void socketClosed()
    {
    }

    void socketError( int e )
    {
         if ( e == TQSocket::ErrHostNotFound ||
              e == TQSocket::ErrConnectionRefused )
            emit fatalError();
    }


private:
    TQSocket *socket;
};

#endif //
